aboutsummaryrefslogtreecommitdiff
path: root/examples/shaders_postprocessing.c
diff options
context:
space:
mode:
authorvictorfisac <victorfisac@gmail.com>2016-07-05 11:57:05 +0200
committervictorfisac <victorfisac@gmail.com>2016-07-05 11:57:05 +0200
commit1aecd5be072083e27e4289499865b5681f1ea656 (patch)
tree808159aa95df9b2be5509d83791aa6cad4ddf6b8 /examples/shaders_postprocessing.c
parent1b0996fb0bcf68e2a14bc6260c6f2c5366ab033f (diff)
parent2ff2096b36d80078cbda5e61ff77d7fedeeeaeb5 (diff)
downloadraylib-1aecd5be072083e27e4289499865b5681f1ea656.tar.gz
raylib-1aecd5be072083e27e4289499865b5681f1ea656.zip
Merge remote-tracking branch 'refs/remotes/raysan5/develop' into develop
Diffstat (limited to 'examples/shaders_postprocessing.c')
-rw-r--r--examples/shaders_postprocessing.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/examples/shaders_postprocessing.c b/examples/shaders_postprocessing.c
index 5e8b5a80..43d21e08 100644
--- a/examples/shaders_postprocessing.c
+++ b/examples/shaders_postprocessing.c
@@ -34,7 +34,7 @@ int main()
Model dwarf = LoadModel("resources/model/dwarf.obj"); // Load OBJ model
Texture2D texture = LoadTexture("resources/model/dwarf_diffuse.png"); // Load model texture (diffuse map)
- SetModelTexture(&dwarf, texture); // Bind texture to model
+ dwarf.material.texDiffuse = texture; // Set dwarf model diffuse texture
Vector3 position = { 0.0f, 0.0f, 0.0f }; // Set model position